==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-ogsabes/src/main/java/de/fzj/unicore/ucc/bes/BESFactoryLister.java <==
package de.fzj.unicore.ucc.bes;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.log4j.Logger;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.bes.BESFactory;
import de.fzj.unicore.bes.client.FactoryClient;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.security.util.Log;
import eu.unicore.security.util.client.IClientProperties;


/**
 * This class lists the available besfactories. 
 *
 * @author m.memon
 */
public class BESFactoryLister implements Iterable<FactoryClient>{

	private static final Logger logger=Logger.getLogger(BESFactoryLister.class.getName());	
	
	private IRegistryQuery registry;

	private IClientProperties securityProperties;

	private List<FactoryClient> factoryList; 

	public BESFactoryLister(IRegistryQuery registry, IClientProperties securityProperties) {
		this.registry = registry;
		this.securityProperties=securityProperties;
		factoryList = new ArrayList<FactoryClient>();
	}	


	/**
	 * lists available factories
	 * 
	 * @throws Exception - in case of registry connection problems
	 */
	public List<FactoryClient> list()throws Exception{
		List<EndpointReferenceType> eprs; 
		eprs = registry.listAccessibleServices(BESFactory.BES_PORT);
		FactoryClient fClient;
		for (EndpointReferenceType e : eprs) {
			try{
				fClient = new FactoryClient(e.getAddress().getStringValue(), e, securityProperties);
				factoryList.add(fClient);
			} catch (Exception ex) {
				Log.logException("Error connecting to BESFactory "+e.getAddress().getStringValue(),ex,logger);
			}
		}
		return factoryList;
	}


	public Iterator<FactoryClient> iterator(){
		try{
			return list().iterator();
		}catch(Exception ex){
			throw new RuntimeException(ex);
		}
	}

}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-ogsabes/src/main/java/de/fzj/unicore/ucc/bes/BESFactoryLister.java <==
package de.fzj.unicore.ucc.bes;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.log4j.Logger;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.bes.BESFactory;
import de.fzj.unicore.bes.client.FactoryClient;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.util.Log;
import eu.unicore.util.httpclient.IClientConfiguration;


/**
 * This class lists the available besfactories. 
 *
 * @author m.memon
 */
public class BESFactoryLister implements Iterable<FactoryClient>{

	private static final Logger logger=Logger.getLogger(BESFactoryLister.class.getName());	
	
	private IRegistryQuery registry;

	private IClientConfiguration securityProperties;

	private List<FactoryClient> factoryList; 

	public BESFactoryLister(IRegistryQuery registry, IClientConfiguration securityProperties) {
		this.registry = registry;
		this.securityProperties=securityProperties;
		factoryList = new ArrayList<FactoryClient>();
	}	


	/**
	 * lists available factories
	 * 
	 * @throws Exception - in case of registry connection problems
	 */
	public List<FactoryClient> list()throws Exception{
		List<EndpointReferenceType> eprs; 
		eprs = registry.listAccessibleServices(BESFactory.BES_PORT);
		FactoryClient fClient;
		for (EndpointReferenceType e : eprs) {
			try{
				fClient = new FactoryClient(e.getAddress().getStringValue(), e, securityProperties);
				factoryList.add(fClient);
			} catch (Exception ex) {
				Log.logException("Error connecting to BESFactory "+e.getAddress().getStringValue(),ex,logger);
			}
		}
		return factoryList;
	}


	public Iterator<FactoryClient> iterator(){
		try{
			return list().iterator();
		}catch(Exception ex){
			throw new RuntimeException(ex);
		}
	}

}
